@@ -752,7 +752,7 @@ static void
 write_exif_undefined_tag (GstExifWriter * writer, guint16 tag,
     const guint8 * data, gint size)
 {
-  guint32 offset;
+  guint32 offset = 0;
 
   if (size > 4) {
     /* we only use the data offset here, later we add up the
@@ -773,7 +773,7 @@ static void
 write_exif_ascii_tag (GstExifWriter * writer, guint16 tag, const gchar * str)
 {
   gint size;
-  guint32 offset;
+  guint32 offset = 0;
 
   size = strlen (str) + 1;
 
@@ -1148,9 +1148,12 @@ parse_exif_ascii_tag (GstExifReader * reader, const GstExifTagMatch * tag,
 
     if (sscanf (str, "%04d:%02d:%02d %02d:%02d:%02d", &year, &month, &day,
             &hour, &minute, &second) > 0) {
-      gst_tag_list_add (reader->taglist, GST_TAG_MERGE_REPLACE, tag->gst_tag,
-          gst_date_time_new_local_time (year, month, day, hour, minute,
-              second), NULL);
+      GstDateTime *d;
+
+      d = gst_date_time_new_local_time (year, month, day, hour, minute, second);
+      gst_tag_list_add (reader->taglist, GST_TAG_MERGE_REPLACE,
+          tag->gst_tag, d, NULL);
+      gst_date_time_unref (d);
     } else {
       GST_WARNING ("Failed to parse %s into a datetime tag", str);
     }
@@ -1220,8 +1223,12 @@ parse_exif_undefined_tag (GstExifReader * reader, const GstExifTagMatch * tag,
 
   tagtype = gst_tag_get_type (tag->gst_tag);
   if (tagtype == GST_TYPE_BUFFER) {
-    GstBuffer *buf = gst_buffer_new ();
-    gst_buffer_set_data (buf, data, count);
+    GstBuffer *buf;
+
+    buf = gst_buffer_new ();
+    GST_BUFFER_DATA (buf) = data;
+    GST_BUFFER_MALLOCDATA (buf) = data;
+    GST_BUFFER_SIZE (buf) = count;
     data = NULL;
 
     gst_tag_list_add (reader->taglist, GST_TAG_MERGE_APPEND, tag->gst_tag,
