@@ -47,6 +47,92 @@ static void glue (uyvy422_to_, RGB_NAME)(AVPicture *dst, const AVPicture *src,
 
             s1 += 4;
         }
+
+        if (w) {
+            YUV_TO_RGB1_CCIR(s1[0], s1[2]);
+
+            YUV_TO_RGB2_CCIR(r, g, b, s1[1]);
+            RGB_OUT(d1, r, g, b);
+        }
+
+        d += dst->linesize[0];
+        s += src->linesize[0];
+    }
+}
+
+static void glue (yuv422_to_, RGB_NAME)(AVPicture *dst, const AVPicture *src,
+                                        int width, int height)
+{
+    uint8_t *s, *d, *d1, *s1;
+    int w, y, cb, cr, r_add, g_add, b_add;
+    uint8_t *cm = cropTbl + MAX_NEG_CROP;
+    unsigned int r, g, b;
+
+    d = dst->data[0];
+    s = src->data[0];
+    for(;height > 0; height --) {
+        d1 = d;
+        s1 = s;
+        for(w = width; w >= 2; w -= 2) {
+            YUV_TO_RGB1_CCIR(s1[1], s1[3]);
+
+            YUV_TO_RGB2_CCIR(r, g, b, s1[0]);
+            RGB_OUT(d1, r, g, b);
+            d1 += BPP;
+
+            YUV_TO_RGB2_CCIR(r, g, b, s1[2]);
+            RGB_OUT(d1, r, g, b);
+            d1 += BPP;
+
+            s1 += 4;
+        }
+
+        if (w) {
+            YUV_TO_RGB1_CCIR(s1[1], s1[3]);
+
+            YUV_TO_RGB2_CCIR(r, g, b, s1[0]);
+            RGB_OUT(d1, r, g, b);
+        }
+
+        d += dst->linesize[0];
+        s += src->linesize[0];
+    }
+}
+
+static void glue (yvyu422_to_, RGB_NAME)(AVPicture *dst, const AVPicture *src,
+                                        int width, int height)
+{
+    uint8_t *s, *d, *d1, *s1;
+    int w, y, cb, cr, r_add, g_add, b_add;
+    uint8_t *cm = cropTbl + MAX_NEG_CROP;
+    unsigned int r, g, b;
+
+    d = dst->data[0];
+    s = src->data[0];
+    for(;height > 0; height --) {
+        d1 = d;
+        s1 = s;
+        for(w = width; w >= 2; w -= 2) {
+            YUV_TO_RGB1_CCIR(s1[3], s1[1]);
+
+            YUV_TO_RGB2_CCIR(r, g, b, s1[0]);
+            RGB_OUT(d1, r, g, b);
+            d1 += BPP;
+
+            YUV_TO_RGB2_CCIR(r, g, b, s1[2]);
+            RGB_OUT(d1, r, g, b);
+            d1 += BPP;
+
+            s1 += 4;
+        }
+
+        if (w) {
+            YUV_TO_RGB1_CCIR(s1[3], s1[1]);
+
+            YUV_TO_RGB2_CCIR(r, g, b, s1[0]);
+            RGB_OUT(d1, r, g, b);
+        }
+
         d += dst->linesize[0];
         s += src->linesize[0];
     }
@@ -146,6 +232,129 @@ static void glue (yuv420p_to_, RGB_NAME)(AVPicture *dst, const AVPicture *src,
   }
 }
 
+#ifndef RGBA_OUT
+#define RGBA_OUT_(d, r, g, b, a) RGB_OUT(d, r, g, b)
+#define YUVA_TO_A(d, a)
+#else
+#define RGBA_OUT_(d, r, g, b, a) RGBA_OUT(d, r, g, b, a)
+#define YUVA_TO_A(d, a) do { d = a; } while (0);
+#endif
+
+static void glue (yuva420p_to_, RGB_NAME)(AVPicture *dst, const AVPicture *src,
+                                        int width, int height)
+{
+  const uint8_t *y1_ptr, *y2_ptr, *cb_ptr, *cr_ptr, *a1_ptr, *a2_ptr;
+  uint8_t *d, *d1, *d2;
+  int w, y, cb, cr, r_add, g_add, b_add, width2;
+  uint8_t *cm = cropTbl + MAX_NEG_CROP;
+  unsigned int r, g, b;
+#ifdef RGBA_OUT
+  unsigned int a = 0;
+#endif
+
+  d = dst->data[0];
+  y1_ptr = src->data[0];
+  cb_ptr = src->data[1];
+  cr_ptr = src->data[2];
+  a1_ptr = src->data[3];
+  width2 = (width + 1) >> 1;
+  for (; height >= 2; height -= 2) {
+    d1 = d;
+    d2 = d + dst->linesize[0];
+    y2_ptr = y1_ptr + src->linesize[0];
+    a2_ptr = a1_ptr + src->linesize[3];
+    for (w = width; w >= 2; w -= 2) {
+      YUVA_TO_A (a, a1_ptr[0]);
+      YUV_TO_RGB1_CCIR (cb_ptr[0], cr_ptr[0]);
+      /* output 4 pixels */
+      YUV_TO_RGB2_CCIR (r, g, b, y1_ptr[0]);
+      RGBA_OUT_ (d1, r, g, b, a);
+
+      YUVA_TO_A (a, a1_ptr[1]);
+      YUV_TO_RGB2_CCIR (r, g, b, y1_ptr[1]);
+      RGBA_OUT_ (d1 + BPP, r, g, b, a);
+
+      YUVA_TO_A (a, a2_ptr[0]);
+      YUV_TO_RGB2_CCIR (r, g, b, y2_ptr[0]);
+      RGBA_OUT_ (d2, r, g, b, a);
+
+      YUVA_TO_A (a, a2_ptr[1]);
+      YUV_TO_RGB2_CCIR (r, g, b, y2_ptr[1]);
+      RGBA_OUT_ (d2 + BPP, r, g, b, a);
+
+      d1 += 2 * BPP;
+      d2 += 2 * BPP;
+
+      y1_ptr += 2;
+      y2_ptr += 2;
+      cb_ptr++;
+      cr_ptr++;
+      a1_ptr += 2;
+      a2_ptr += 2;
+    }
+    /* handle odd width */
+    if (w) {
+      YUVA_TO_A (a, a1_ptr[0]);
+      YUV_TO_RGB1_CCIR (cb_ptr[0], cr_ptr[0]);
+      YUV_TO_RGB2_CCIR (r, g, b, y1_ptr[0]);
+      RGBA_OUT_ (d1, r, g, b, a);
+
+      YUVA_TO_A (a, a2_ptr[0]);
+      YUV_TO_RGB2_CCIR (r, g, b, y2_ptr[0]);
+      RGBA_OUT_ (d2, r, g, b, a);
+      d1 += BPP;
+      d2 += BPP;
+      y1_ptr++;
+      y2_ptr++;
+      cb_ptr++;
+      cr_ptr++;
+      a1_ptr++;
+      a2_ptr++;
+    }
+    d += 2 * dst->linesize[0];
+    y1_ptr += 2 * src->linesize[0] - width;
+    cb_ptr += src->linesize[1] - width2;
+    cr_ptr += src->linesize[2] - width2;
+    a1_ptr += 2 * src->linesize[3] - width;
+  }
+  /* handle odd height */
+  if (height) {
+    d1 = d;
+    for (w = width; w >= 2; w -= 2) {
+      YUVA_TO_A (a, a1_ptr[0]);
+      YUV_TO_RGB1_CCIR (cb_ptr[0], cr_ptr[0]);
+      /* output 2 pixels */
+      YUV_TO_RGB2_CCIR (r, g, b, y1_ptr[0]);
+      RGBA_OUT_ (d1, r, g, b, a);
+
+      YUVA_TO_A (a, a1_ptr[1]);
+      YUV_TO_RGB2_CCIR (r, g, b, y1_ptr[1]);
+      RGBA_OUT_ (d1 + BPP, r, g, b, a);
+
+      d1 += 2 * BPP;
+
+      y1_ptr += 2;
+      cb_ptr++;
+      cr_ptr++;
+      a1_ptr += 2;
+    }
+    /* handle width */
+    if (w) {
+      YUVA_TO_A (a, a1_ptr[0]);
+      YUV_TO_RGB1_CCIR (cb_ptr[0], cr_ptr[0]);
+      /* output 2 pixel */
+      YUV_TO_RGB2_CCIR (r, g, b, y1_ptr[0]);
+      RGBA_OUT_ (d1, r, g, b, a);
+      d1 += BPP;
+
+      y1_ptr++;
+      cb_ptr++;
+      cr_ptr++;
+      a1_ptr++;
+    }
+  }
+}
+
 static void glue (nv12_to_, RGB_NAME) (AVPicture * dst, const AVPicture * src,
     int width, int height)
 {
@@ -416,6 +625,60 @@ static void glue (yuvj420p_to_, RGB_NAME) (AVPicture * dst,
   }
 }
 
+static void glue (y800_to_, RGB_NAME) (AVPicture * dst, const AVPicture * src,
+    int width, int height)
+{
+  const unsigned char *p;
+  unsigned char *q;
+  uint8_t *cm = cropTbl + MAX_NEG_CROP;
+  int r, dst_wrap, src_wrap;
+  int x, y;
+
+  p = src->data[0];
+  src_wrap = src->linesize[0] - width;
+
+  q = dst->data[0];
+  dst_wrap = dst->linesize[0] - BPP * width;
+
+  for (y = 0; y < height; y++) {
+    for (x = 0; x < width; x++) {
+      r = Y_CCIR_TO_JPEG (p[0]);
+      RGB_OUT (q, r, r, r);
+      q += BPP;
+      p++;
+    }
+    p += src_wrap;
+    q += dst_wrap;
+  }
+}
+
+static void glue (y16_to_, RGB_NAME) (AVPicture * dst,
+    const AVPicture * src, int width, int height)
+{
+  const unsigned char *p;
+  unsigned char *q;
+  uint8_t *cm = cropTbl + MAX_NEG_CROP;
+  int r, dst_wrap, src_wrap;
+  int x, y;
+
+  p = src->data[0];
+  src_wrap = src->linesize[0] - 2 * width;
+
+  q = dst->data[0];
+  dst_wrap = dst->linesize[0] - BPP * width;
+
+  for (y = 0; y < height; y++) {
+    for (x = 0; x < width; x++) {
+      r = Y_CCIR_TO_JPEG (GST_READ_UINT16_LE (p) >> 8);
+      RGB_OUT (q, r, r, r);
+      q += BPP;
+      p += 2;
+    }
+    p += src_wrap;
+    q += dst_wrap;
+  }
+}
+
 static void glue (RGB_NAME, _to_yuv420p) (AVPicture * dst,
     const AVPicture * src, int width, int height)
 {
@@ -524,6 +787,135 @@ static void glue (RGB_NAME, _to_yuv420p) (AVPicture * dst,
   }
 }
 
+#ifndef RGBA_IN
+#define RGBA_IN_(r, g, b, a, p) RGB_IN(r, g, b, p)
+#else
+#define RGBA_IN_(r, g, b, a, p) RGBA_IN(r, g, b, a, p)
+#endif
+
+static void glue (RGB_NAME, _to_yuva420p) (AVPicture * dst,
+    const AVPicture * src, int width, int height)
+{
+  int wrap, wrap3, width2;
+  int r, g, b, r1, g1, b1, w, ra = 255;
+  uint8_t *lum, *cb, *cr, *a;
+  const uint8_t *p;
+
+  lum = dst->data[0];
+  cb = dst->data[1];
+  cr = dst->data[2];
+  a = dst->data[3];
+
+  width2 = (width + 1) >> 1;
+  wrap = dst->linesize[0];
+  wrap3 = src->linesize[0];
+  p = src->data[0];
+  for (; height >= 2; height -= 2) {
+    for (w = width; w >= 2; w -= 2) {
+      RGBA_IN_ (r, g, b, ra, p);
+      r1 = r;
+      g1 = g;
+      b1 = b;
+      lum[0] = RGB_TO_Y_CCIR (r, g, b);
+      a[0] = ra;
+
+      RGBA_IN_ (r, g, b, ra, p + BPP);
+      r1 += r;
+      g1 += g;
+      b1 += b;
+      lum[1] = RGB_TO_Y_CCIR (r, g, b);
+      a[1] = ra;
+      p += wrap3;
+      lum += wrap;
+      a += wrap;
+
+      RGBA_IN_ (r, g, b, ra, p);
+      r1 += r;
+      g1 += g;
+      b1 += b;
+      lum[0] = RGB_TO_Y_CCIR (r, g, b);
+      a[0] = ra;
+
+      RGBA_IN_ (r, g, b, ra, p + BPP);
+      r1 += r;
+      g1 += g;
+      b1 += b;
+      lum[1] = RGB_TO_Y_CCIR (r, g, b);
+      a[1] = ra;
+
+      cb[0] = RGB_TO_U_CCIR (r1, g1, b1, 2);
+      cr[0] = RGB_TO_V_CCIR (r1, g1, b1, 2);
+
+      cb++;
+      cr++;
+      p += -wrap3 + 2 * BPP;
+      lum += -wrap + 2;
+      a += -wrap + 2;
+    }
+    if (w) {
+      RGBA_IN_ (r, g, b, ra, p);
+      r1 = r;
+      g1 = g;
+      b1 = b;
+      lum[0] = RGB_TO_Y_CCIR (r, g, b);
+      a[0] = ra;
+      p += wrap3;
+      lum += wrap;
+      a += wrap;
+      RGBA_IN_ (r, g, b, ra, p);
+      r1 += r;
+      g1 += g;
+      b1 += b;
+      lum[0] = RGB_TO_Y_CCIR (r, g, b);
+      a[0] = ra;
+      cb[0] = RGB_TO_U_CCIR (r1, g1, b1, 1);
+      cr[0] = RGB_TO_V_CCIR (r1, g1, b1, 1);
+      cb++;
+      cr++;
+      p += -wrap3 + BPP;
+      lum += -wrap + 1;
+      a += -wrap + 1;
+    }
+    p += wrap3 + (wrap3 - width * BPP);
+    lum += wrap + (wrap - width);
+    a += wrap + (wrap - width);
+    cb += dst->linesize[1] - width2;
+    cr += dst->linesize[2] - width2;
+  }
+  /* handle odd height */
+  if (height) {
+    for (w = width; w >= 2; w -= 2) {
+      RGBA_IN_ (r, g, b, ra, p);
+      r1 = r;
+      g1 = g;
+      b1 = b;
+      lum[0] = RGB_TO_Y_CCIR (r, g, b);
+      a[0] = ra;
+
+      RGBA_IN_ (r, g, b, ra, p + BPP);
+      r1 += r;
+      g1 += g;
+      b1 += b;
+      lum[1] = RGB_TO_Y_CCIR (r, g, b);
+      a[1] = ra;
+      cb[0] = RGB_TO_U_CCIR (r1, g1, b1, 1);
+      cr[0] = RGB_TO_V_CCIR (r1, g1, b1, 1);
+      cb++;
+      cr++;
+      p += 2 * BPP;
+      lum += 2;
+      a += 2;
+    }
+    if (w) {
+      RGBA_IN_ (r, g, b, ra, p);
+      lum[0] = RGB_TO_Y_CCIR (r, g, b);
+      a[0] = ra;
+      cb[0] = RGB_TO_U_CCIR (r, g, b, 0);
+      cr[0] = RGB_TO_V_CCIR (r, g, b, 0);
+    }
+  }
+}
+
 static void glue (RGB_NAME, _to_nv12) (AVPicture * dst, const AVPicture * src,
     int width, int height)
 {
@@ -756,6 +1148,58 @@ static void glue (RGB_NAME, _to_gray) (AVPicture * dst, const AVPicture * src,
   }
 }
 
+static void glue (RGB_NAME, _to_y800) (AVPicture * dst, const AVPicture * src,
+    int width, int height)
+{
+  const unsigned char *p;
+  unsigned char *q;
+  int r, g, b, dst_wrap, src_wrap;
+  int x, y;
+
+  p = src->data[0];
+  src_wrap = src->linesize[0] - BPP * width;
+
+  q = dst->data[0];
+  dst_wrap = dst->linesize[0] - width;
+
+  for (y = 0; y < height; y++) {
+    for (x = 0; x < width; x++) {
+      RGB_IN (r, g, b, p);
+      q[0] = RGB_TO_Y_CCIR (r, g, b);
+      q++;
+      p += BPP;
+    }
+    p += src_wrap;
+    q += dst_wrap;
+  }
+}
+
+static void glue (RGB_NAME, _to_y16) (AVPicture * dst,
+    const AVPicture * src, int width, int height)
+{
+  const unsigned char *p;
+  unsigned char *q;
+  int r, g, b, dst_wrap, src_wrap;
+  int x, y;
+
+  p = src->data[0];
+  src_wrap = src->linesize[0] - BPP * width;
+
+  q = dst->data[0];
+  dst_wrap = dst->linesize[0] - 2 * width;
+
+  for (y = 0; y < height; y++) {
+    for (x = 0; x < width; x++) {
+      RGB_IN (r, g, b, p);
+      GST_WRITE_UINT16_LE (q, RGB_TO_Y_CCIR (r, g, b) << 8);
+      q += 2;
+      p += BPP;
+    }
+    p += src_wrap;
+    q += dst_wrap;
+  }
+}
+
 static void glue (gray_to_, RGB_NAME) (AVPicture * dst, const AVPicture * src,
     int width, int height)
 {
@@ -1083,10 +1527,167 @@ bgra32_to_ayuv4444 (AVPicture * dst, const AVPicture * src,
   }
 }
 
+static void
+ayuv4444_to_bgra32 (AVPicture * dst, const AVPicture * src,
+    int width, int height)
+{
+  uint8_t *s, *d, *d1, *s1;
+  int w, y, cb, cr, r_add, g_add, b_add;
+  uint8_t *cm = cropTbl + MAX_NEG_CROP;
+  unsigned int r, g, b, a;
+
+  d = dst->data[0];
+  s = src->data[0];
+  for (; height > 0; height--) {
+    d1 = d;
+    s1 = s;
+    for (w = width; w > 0; w--) {
+      a = s1[0];
+      YUV_TO_RGB1_CCIR (s1[2], s1[3]);
+
+      YUV_TO_RGB2_CCIR (r, g, b, s1[1]);
+      RGBA_OUT (d1, r, g, b, a);
+      d1 += BPP;
+      s1 += 4;
+    }
+    d += dst->linesize[0];
+    s += src->linesize[0];
+  }
+}
+
 #endif /* !defined(bgra32_fcts_done) */
 
 #endif /* defined(FMT_BGRA32) */
 
+#if defined(FMT_ARGB32)
+
+#if !defined(argb32_fcts_done)
+#define argb32_fcts_done
+
+static void
+ayuv4444_to_argb32 (AVPicture * dst, const AVPicture * src,
+    int width, int height)
+{
+  uint8_t *s, *d, *d1, *s1;
+  int w, y, cb, cr, r_add, g_add, b_add;
+  uint8_t *cm = cropTbl + MAX_NEG_CROP;
+  unsigned int r, g, b, a;
+
+  d = dst->data[0];
+  s = src->data[0];
+  for (; height > 0; height--) {
+    d1 = d;
+    s1 = s;
+    for (w = width; w > 0; w--) {
+      a = s1[0];
+      YUV_TO_RGB1_CCIR (s1[2], s1[3]);
+
+      YUV_TO_RGB2_CCIR (r, g, b, s1[1]);
+      RGBA_OUT (d1, r, g, b, a);
+      d1 += BPP;
+      s1 += 4;
+    }
+    d += dst->linesize[0];
+    s += src->linesize[0];
+  }
+}
+
+static void
+argb32_to_ayuv4444 (AVPicture * dst, const AVPicture * src,
+    int width, int height)
+{
+  int src_wrap, dst_wrap, x, y;
+  int r, g, b, a;
+  uint8_t *d;
+  const uint8_t *p;
+
+  src_wrap = src->linesize[0] - width * BPP;
+  dst_wrap = dst->linesize[0] - width * 4;
+  d = dst->data[0];
+  p = src->data[0];
+  for (y = 0; y < height; y++) {
+    for (x = 0; x < width; x++) {
+      RGBA_IN (r, g, b, a, p);
+      d[0] = a;
+      d[1] = RGB_TO_Y_CCIR (r, g, b);
+      d[2] = RGB_TO_U_CCIR (r, g, b, 0);
+      d[3] = RGB_TO_V_CCIR (r, g, b, 0);
+      p += BPP;
+      d += 4;
+    }
+    p += src_wrap;
+    d += dst_wrap;
+  }
+}
+
+#endif /* !defined(argb32_fcts_done) */
+
+#endif /* defined(FMT_ARGB32) */
+
+#if defined(FMT_ABGR32)
+#if !defined(abgr32_fcts_done)
+#define abgr32_fcts_done
+
+static void
+abgr32_to_ayuv4444 (AVPicture * dst, const AVPicture * src,
+    int width, int height)
+{
+  int src_wrap, dst_wrap, x, y;
+  int r, g, b, a;
+  uint8_t *d;
+  const uint8_t *p;
+
+  src_wrap = src->linesize[0] - width * BPP;
+  dst_wrap = dst->linesize[0] - width * 4;
+  d = dst->data[0];
+  p = src->data[0];
+  for (y = 0; y < height; y++) {
+    for (x = 0; x < width; x++) {
+      RGBA_IN (r, g, b, a, p);
+      d[0] = a;
+      d[1] = RGB_TO_Y_CCIR (r, g, b);
+      d[2] = RGB_TO_U_CCIR (r, g, b, 0);
+      d[3] = RGB_TO_V_CCIR (r, g, b, 0);
+      p += BPP;
+      d += 4;
+    }
+    p += src_wrap;
+    d += dst_wrap;
+  }
+}
+
+static void
+ayuv4444_to_abgr32 (AVPicture * dst, const AVPicture * src,
+    int width, int height)
+{
+  uint8_t *s, *d, *d1, *s1;
+  int w, y, cb, cr, r_add, g_add, b_add;
+  uint8_t *cm = cropTbl + MAX_NEG_CROP;
+  unsigned int r, g, b, a;
+
+  d = dst->data[0];
+  s = src->data[0];
+  for (; height > 0; height--) {
+    d1 = d;
+    s1 = s;
+    for (w = width; w > 0; w--) {
+      a = s1[0];
+      YUV_TO_RGB1_CCIR (s1[2], s1[3]);
+
+      YUV_TO_RGB2_CCIR (r, g, b, s1[1]);
+      RGBA_OUT (d1, r, g, b, a);
+      d1 += BPP;
+      s1 += 4;
+    }
+    d += dst->linesize[0];
+    s += src->linesize[0];
+  }
+}
+
+#endif /* !defined(abgr32_fcts_done) */
+
+#endif /* defined(FMT_ABGR32) */
+
 #ifndef FMT_RGB24
 
 static void glue (rgb24_to_, RGB_NAME) (AVPicture * dst, const AVPicture * src,
@@ -1582,3 +2183,6 @@ static int glue (get_alpha_info_, RGB_NAME) (const AVPicture * src,
 #undef RGB_NAME
 #undef FMT_RGB24
 #undef FMT_RGBA32
+#undef YUVA_TO_A
+#undef RGBA_OUT_
+#undef RGBA_IN_
