@@ -40,13 +40,6 @@
 
 #include "gstgdppay.h"
 
-/* elementfactory information */
-static const GstElementDetails gdp_pay_details =
-GST_ELEMENT_DETAILS ("GDP Payloader",
-    "GDP/Payloader",
-    "Payloads GStreamer Data Protocol buffers",
-    "Thomas Vander Stichele <thomas at apestaart dot org>");
-
 static GstStaticPadTemplate gdp_pay_sink_template =
 GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_SINK,
@@ -104,7 +97,10 @@ gst_gdp_pay_base_init (gpointer g_class)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (g_class);
 
-  gst_element_class_set_details (element_class, &gdp_pay_details);
+  gst_element_class_set_details_simple (element_class,
+      "GDP Payloader", "GDP/Payloader",
+      "Payloads GStreamer Data Protocol buffers",
+      "Thomas Vander Stichele <thomas at apestaart dot org>");
 
   gst_element_class_add_pad_template (element_class,
       gst_static_pad_template_get (&gdp_pay_sink_template));
@@ -479,6 +475,8 @@ gst_gdp_pay_reset_streamheader (GstGDPPay * this)
   GST_DEBUG_OBJECT (this, "Setting caps on src pad %" GST_PTR_FORMAT, caps);
   gst_pad_set_caps (this->srcpad, caps);
   gst_buffer_set_caps (this->caps_buf, caps);
+  this->new_segment_buf =
+      gst_buffer_make_metadata_writable (this->new_segment_buf);
   gst_buffer_set_caps (this->new_segment_buf, caps);
 
   /* if these are our first ever buffers, send out new_segment first */
